@@ -27,7 +27,12 @@ def _download(args):
 	"""
 	
 	base = "http://lyrics.wikia.com/api.php?"
-	args = urllib.urlencode(args)
+	
+	str_args = {}
+	for key in args:
+		str_args[key] = args[key].encode("utf-8")
+	
+	args = urllib.urlencode(str_args)
 	
 	return urllib.urlopen(base + args).read()
 
@@ -45,8 +50,11 @@ def _get_lyrics(page_title):
 		return None
 		
 	content = revisions["revisions"][0]["*"]
+	
 	if "<lyrics>" in content:
 		return content[content.find("<lyrics>") + len("<lyrics>") : content.find("</lyrics>")].strip()
+	elif "<lyric>" in content:
+		return content[content.find("<lyric>") + len("<lyric>") : content.find("</lyric>")].strip()
 
 def get_lyrics(artist, title):
 	"""
